---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Environment(please complete the following information):**
 - OS: [e.g. Devuan GNU/Linux]
 - MySQL Version[e.g. 5.7.27]
 - PostgreSQL Version[e.g. 11]
 - Python Version [e.g. 3.5]
 - Cloud hosted database [e.g PostgreSQL on AWS RDS and MySQL on Google Cloud] 

**Additional context**
Add any other context about the problem here.
